/*
 * Order.java
 *
 * Created on April 18, 2006, 3:26 PM
 *
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "LICENSE"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  SUN
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */

package javaone.sample.persistence;

/**
 *
 * @author Rahul Biswas
 */
import java.util.Collection;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Entity;
import javax.persistence.*;

@Entity()
@Table(name="J1Order")
@Inheritance(strategy=InheritanceType.SINGLE_TABLE) 
@SecondaryTable(name="ORDER_SEC")
@NamedQuery(name="queryOrder", query="select OBJECT(o) from Order o where o.id=:id")
public class Order {
    
    /** Creates a new instance of Order */
    public Order() {
    }
    
    private Collection<OrderLineItem> lineItems;
    private String id;
    private Customer customer;
    private Carrier carrier;
    private String description;
    
    //secondary table stuff
    private String name;
    private String revision;
            
    @Id
    @TableGenerator(name="ORDER_PK_GEN", table="ORDER_PK_GEN")        
    @GeneratedValue(strategy=GenerationType.TABLE, generator="ORDER_PK_GEN")
    public String getId(){
        return id;
    }
    
    public void setId(String id){
        this.id=id;
    }
    
    @OneToMany(cascade=CascadeType.ALL, fetch=FetchType.LAZY, mappedBy="order")
    public Collection<OrderLineItem> getLineItems(){
        return lineItems;
    }
    
    public void setLineItems(Collection<OrderLineItem> lineItems){
        this.lineItems = lineItems;
    }
    
    public void addLineItem(OrderLineItem lineItem){
        this.lineItems.add(lineItem);
    }
    
    @ManyToOne
    public Customer getCustomer(){
        return customer;
    }
    public void setCustomer(Customer customer){
        this.customer = customer;
    }
    
    @ManyToOne
    public Carrier getCarrier(){
        return carrier;
    }
    
    public void setCarrier(Carrier carrier){
        this.carrier=carrier;
    }
    
    public void setDescription(String desc){
        this.description=desc;
    }

    public String getDescription(){
        return description;
    }
    
    @Column(table="ORDER_SEC")
    public String getName(){
        return name;
    }
    
    public void setName(String name){
        this.name=name;
    }
    
    @Column(table="ORDER_SEC")
    public String getRevision(){
        return revision;
    }
    public void setRevision(String revision){
        this.revision=revision;
    }
    
}
