/*
 * OrderLineItem.java
 *
 * Created on April 18, 2006, 3:26 PM
 *
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "LICENSE"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  SUN
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */

package javaone.sample.persistence;

/**
 *
 * @author Rahul Biswas
 */

import java.util.Collection;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.*;

@Entity
@NamedQuery(name="findLineItemByType", query="SELECT OBJECT(li) from OrderLineItem li where li.type=:type AND li.order.id=:id")
public class OrderLineItem {
    
    /** Creates a new instance of OrderLineItem */
    public OrderLineItem() {
    }
    
    private String id;
    private String type="NORMAL";
    private float price;
    
    private Collection<OrderLineItem> lineItems;
    private Order order;
    private OrderLineItem parent;

    
    @Id
    @GeneratedValue(strategy=GenerationType.AUTO)
    public String getId(){
        return id;
    }
    
    public void setId(String id){
        this.id=id;
    }
    
    @OneToMany(cascade=CascadeType.ALL, fetch=FetchType.LAZY, mappedBy="parent")
    public Collection<OrderLineItem> getLineItems(){
        return lineItems;
    }
    
    public void setLineItems(Collection<OrderLineItem> lineItems){
        this.lineItems = lineItems;
    }
    
    public void addLineItem(OrderLineItem lineItem){
        this.lineItems.add(lineItem);
    }
    
    @ManyToOne//(fetch=FetchType.LAZY)
    public Order getOrder(){
        return order;
    }
    
    public void setOrder(Order order){
        this.order=order;
    }
    
    @ManyToOne//(fetch=FetchType.LAZY)
    public OrderLineItem getParent(){
        return parent;
    }
    
    public void setParent(OrderLineItem lineItem){
        this.parent=lineItem;
    }
    
    public String getType(){
        return type;
    }
    
    public void setType(String type){
        this.type=type;
    }
    
    public float getPrice(){
        return price;
    }
    
    public void setPrice(float price){
        this.price=price;
    }
}
